@@ -9,7 +9,7 @@
 import re
 
 
-def camel_case_to_underscore(name: str) -> str:
-    string = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
+def camel_case_to_underscore(raw_string: str) -> str:
+    string = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', raw_string)
     return re.sub('([a-z0-9])([A-Z])', r'\1_\2', string).lower()
 
